# Python3 packaging is turned off until pagure itself is ported to python3.
%global with_python3 1

# Current EL releases & older Fedora use "python-*"
%if 0%{?el6} || 0%{?el7} || 0%{?fedora} < 25
%define py_prefix python
%global with_python3 0
%if 0%{?el6} || 0%{?el7}
BuildRequires: python-devel
%else
BuildRequires: python2-devel
%endif
%else
# Newer Fedora releases use "pythonX-*"
%define py_prefix python2
BuildRequires: python2-devel
%endif


%{!?_licensedir: %global license %%doc}

%global modname pagure-dist-git
%global sum     Pagure Git auth backend for Fedora and CentOS dist-git setups

Name:               pagure-dist-git
Version:            1.0
Release:            1%{?dist}
Summary:            %{sum}

License:            GPLv2+
URL:                http://pypi.python.org/pypi/pagure-dist-git
Source0:            https://pypi.io/packages/source/p/%{modname}/%{modname}-%{version}.tar.gz
BuildArch:          noarch
# https://fedoraproject.org/wiki/Packaging:Guidelines#Noarch_with_Unported_Dependencies
ExclusiveArch:      x86_64 noarch


%description
This implements access control list checks for Fedora and CentOS dist-git.

%package -n %{py_prefix}-%{modname}
Summary:            Pagure Git auth backend for Fedora and CentOS dist-git
%{?python_provide:%python_provide python2-%{modname}}

BuildRequires:      %{py_prefix}-devel
BuildRequires:      %{py_prefix}-setuptools
# For tests
BuildRequires:      %{py_prefix}-mock
BuildRequires:      %{py_prefix}-pdc-client
BuildRequires:      %{py_prefix}-nose
BuildRequires:      pagure >= 5.1

Requires:           pagure >= 5.1

%description -n %{py_prefix}-%{modname}
This implements access control list checks for Fedora and CentOS dist-git.

%if 0%{?with_python3}
%package -n python3-%{modname}
Summary:            Pagure Git auth backend for Fedora and CentOS dist-git
%{?python_provide:%python_provide python3-%{modname}}

BuildRequires:      python3-devel
BuildRequires:      python3-setuptools
# For tests
BuildRequires:      python3-mock
BuildRequires:      python3-pdc-client
BuildRequires:      python3-nose
BuildRequires:      pagure >= 5.1

Requires:           python3-pagure >= 5.1

%description -n python3-%{modname}
This implements access control list checks for Fedora and CentOS dist-git.
%endif

%prep
%autosetup -n %{modname}-%{version}

%build
%py2_build
%if 0%{?with_python3}
%py3_build
%endif

%install
%py2_install
%if 0%{?with_python3}
%py3_install
%endif

# Install the different cron job scripts
mkdir -p $RPM_BUILD_ROOT/%{_libexecdir}/pagure-dist-git/
install -p -m 644 scripts/*.py $RPM_BUILD_ROOT/%{_libexecdir}/pagure-dist-git/


%check
# These tests don't currently pass because Pagure doesn't ship its testsuite
exit 0
nosetests -v
%if 0%{?with_python3}
nosetests-3 -v
%endif

%files -n %{py_prefix}-%{modname}
%doc README.rst
%license LICENSE
%{python2_sitelib}/dist_git_auth.py*
%{python2_sitelib}/pagure_dist_git-%{version}*
%{_libexecdir}/pagure-dist-git/

%if 0%{?with_python3}
%files -n python3-%{modname}
%doc README.rst
%license LICENSE
%{python3_sitelib}/dist_git_auth.py*
%{python3_sitelib}/__pycache__/*
%{python3_sitelib}/pagure_dist_git-%{version}*
%{_libexecdir}/pagure-dist-git/
%endif


%changelog
* Tue Oct 09 2018 Patrick Uiterwijk <puiterwijk@redhat.com> - 1.0-1
- Rewrote to Dynamic auth backend system (new in Pagure 5.0)
- Merged CentOS ACL checks

* Mon Apr 23 2018 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.12-1
- Update to 0.12
- Add namespace to all the url_for() calls
- Make the branch name grey and remove the new PR button for disabled branches
  (querying PDC for that info)
- Add a tag making it obvious when a package is retired on Fedora
- Show disabled branches on main project, ie: *not* forks
- Fix the dist_git_auth backend to the new pagure structure
- Port the different cron scripts to pagure >= 4.0

* Wed Dec 20 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.11.1-1
- Update to 0.11.1
- Ensure releng has always commit ACL
- Do not consider forks when generating the extras JSON files for POC and
  bugzilla

* Tue Nov 28 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.11-1
- Update to 0.11
- Do not take forks into account when retrieving maintainers and watchers (when
  generating the JSON files for bugzilla and owner aliases)
- Do not show the buttons to create new project is pagure is not allowing it
- Make the package description respect new line characters
- Add support for commit flags in the commit view

* Tue Oct 17 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.10-1
- Update to 0.10
- Add a script outputting for each project the people who should be CC'ed
- Add a script outputting for each project the user to put on the -owner alias

* Fri Oct 13 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.9-1
- Update to 0.9
- Show the heads of the branches on the commit list
- Import and customize the user_info template for dist-git

* Fri Oct 06 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.8.1-1
- Update to 0.8.1
- Do not show the banner about disabled PRs on forks

* Wed Oct 04 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.8-2
- Fix installing the different templates in the templates folder

* Wed Oct 04 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.8-1
- Update to 0.8
- Bring Atomic CI results into the pagure experience

* Fri Sep 29 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.7-1
- Update to 0.7
- Fix provenpackager access, they also need branch access
- Add support for the custom username in the SSH URL
- Remove caching when querying PDC so that Gitolite ACLs are not generated
  with stale data (Matt Prahl)
- Warn the committers if PRs are turned off and there is no readme
- Add a small script dumping the main admins of each project in pagure

* Mon Aug 21 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.6-1
- Update to 0.6
- Added a new version of the package sources logo (Ryan Lerch)
- Add a log statement when querying PDC (Ralph Bean)
- Simplify the gitolite rules for forks and add tests for them
- Make the project flake8 valid
- Slightly change text to make it less confusing, per mattdm +1 (Paul W.
  Frields)
- Add support for the provenpackager group in pagure-dist-git
- Adjust the logic to group the users and groups in a single line
- Some package do not allow provenpackager access
- Simplify the index_auth template so it renders faster

* Tue Aug 08 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.5-1
- Update to 0.5
- Drop the delete button when the config is off in repo_info.html
- Add a customized pagure-logo for dist-git
- Add a customized index page to be displayed when the users are logged out
- Drop the + access for the groups, it generates an invalid config
- Give RW+C to the forks
- Include the upstream's url next to the project's description on the overview
- Only compile gitolite's config file

* Mon Jul 24 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.4-1
- Update to 0.4
- Adjust the generation of the configuration with the change made to groups
  (requires pagure >= 3.2)
- Ship a custom repo_info template with information specific for dist-git

* Tue Jul 04 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.3-1
- Update to 0.3
- Adjust the spec file to make it support epel as well as Fedora
- Do not reconfigure the logger when one is already configured
- Rework the plugin to reduce the diff it produces

* Fri Jun 30 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.2-1
- Update to 0.2
- Include the missing entry_point in the setup.py

* Fri Jun 30 2017 Ralph Bean <rbean@redhat.com> - 0.1-1
- Initial packaging for Fedora
